run

Function run 

pub fn run() -> Result<()>
Run the nofs command line application.

Errors

Returns an error if the command fails, invalid arguments are provided, or any file system operation fails.